@@ -65,7 +65,7 @@ def install(email, file, path, user, schedule):
     cron = CronTab(tabfile=tab_file, user=False)
     cron.remove_all()
 
-    command = f'crashalyser --path {path}'
+    command = f'crashalyser run --path {path}'
     if email:
         command = command + f' --email {email}'
     if file:
